@@ -322,9 +322,16 @@ class RPCDispatcher:
         
         for appname in apps:
             # check each app for any rpcmethods
-            app = __import__(appname, globals(), locals(), ['*'])
+            try:
+                app = __import__(appname, globals(), locals(), ['*'])
+            except (ImportError, ValueError):
+                # import throws ValueError on empty "name"
+                continue
+
             for obj in dir(app):
                 method = getattr(app, obj)
+                if isinstance(method, xmlrpclib.ServerProxy):
+                    continue
                 if callable(method) and \
                    hasattr(method, 'is_rpcmethod') and \
                    method.is_rpcmethod == True:
@@ -334,10 +341,8 @@ class RPCDispatcher:
                 elif isinstance(method, types.ModuleType):
                     # if this is not a method and instead a sub-module,
                     # scan the module for methods with @rpcmethod
-                    try:
-                        self.register_rpcmethods(["%s.%s" % (appname, obj)])
-                    except ImportError:
-                        pass
+                    self.register_rpcmethods(["%s.%s" % (appname, obj)])
+                        
 
     
     def jsondispatch(self, raw_post_data, **kwargs):
@@ -366,7 +371,7 @@ class RPCDispatcher:
             try:
                 params, method = xmlrpclib.loads(raw_post_data)
                 return method
-            except Fault:
+            except Exception:
                 return None
         else:
             try:
